package com.kaixed.kchat.data.local.dao

import androidx.paging.PagingSource
import androidx.room.Dao
import androidx.room.Query
import androidx.room.Delete
import androidx.room.Insert
import androidx.room.Update
import com.kaixed.kchat.data.local.entity.Messages

@Dao
interface MessagesDao {

    @Query("select * from messages where talkerId = :contactId and  msgLocalId <= :msgLocalId order by timestamp desc limit :limit")
    suspend fun getMessageByContactId(
        contactId: String,
        msgLocalId: Long,
        limit: Long
    ): List<Messages>

    @Query("select * from messages where talkerId = :contactId order by timestamp desc limit :limit")
    suspend fun getMessageByContactId(contactId: String, limit: Long): List<Messages>

    @Query("SELECT * FROM messages WHERE talkerId = :contactId ORDER BY timestamp DESC LIMIT :limit OFFSET :offset")
    suspend fun getMessagesWithContact(contactId: String, offset: Long, limit: Long): List<Messages>

    @Query("SELECT * FROM messages WHERE talkerId = :contactId AND msgLocalId <= :msgLocalId ORDER BY timestamp DESC LIMIT :limit")
    suspend fun getMoreMessages(contactId: String, msgLocalId: Long, limit: Long): List<Messages>

    @Query("SELECT * FROM messages WHERE talkerId = :contactId AND msgLocalId >= :msgLocalId ORDER BY timestamp DESC")
    suspend fun getAllHistoryMessages(contactId: String, msgLocalId: Long): List<Messages>

    @Query("DELETE FROM messages WHERE talkerId = :contactId")
    suspend fun deleteMessagesByContactId(contactId: String)

    @Query("SELECT * FROM messages WHERE talkerId = :contactId ORDER BY timestamp ASC")
    fun selectHistoryMessages(contactId: String): PagingSource<Int, Messages>

    // ASC 更早的消息在最上面
    @Query("SELECT * FROM messages WHERE talkerId = :contactId ORDER BY timestamp ASC")
    fun getMessagesWithContact(contactId: String): PagingSource<Int, Messages>

    @Query("SELECT * FROM messages WHERE talkerId = :contactId AND msgLocalId < :maxMsgId ORDER BY timestamp ASC LIMIT :limit")
    fun getMessagesBefore(contactId: String, maxMsgId: Long, limit: Int): List<Messages>

    @Insert
    suspend fun insertAll(messages: List<Messages>)

    @Insert
    suspend fun insert(messages: Messages): Long

    @Query("SELECT * FROM messages ORDER BY timestamp DESC")
    fun getMessagesPaged(): PagingSource<Int, Messages>

    @Query("SELECT * FROM messages ORDER BY timestamp DESC")
    fun getPagedMessages(): PagingSource<Int, Messages>

    @Query("SELECT * FROM messages WHERE content LIKE :keyword")
    suspend fun getMessagesContainingKeyword(keyword: String): List<Messages>

    @Query("SELECT * FROM messages WHERE talkerId = :talkerId AND timestamp <= :currentTimestamp ORDER BY timestamp DESC LIMIT 1")
    suspend fun getLatestMessage(talkerId: String, currentTimestamp: Long): Messages?

    @Query("SELECT * FROM messages WHERE msgLocalId = :localId")
    suspend fun getMessageByLocalId(localId: Long): Messages

    @Update
    suspend fun updateMessage(messages: Messages)

    @Query("SELECT * FROM messages WHERE talkerId = :talkerId ORDER BY timestamp DESC")
    fun getPagedMessages(talkerId: String): PagingSource<Int, Messages>
}