package com.kaixed.kchat.data.repository

import com.kaixed.kchat.data.local.dao.UserInfoDao
import com.kaixed.kchat.data.local.entity.UserInfo
import com.kaixed.kchat.data.model.request.UpdatePasswordRequest
import com.kaixed.kchat.data.model.request.UserRequest
import com.kaixed.kchat.data.model.search.SearchUser
import com.kaixed.kchat.network.ApiCall.apiCall
import com.kaixed.kchat.network.RetrofitClient
import com.kaixed.kchat.utils.Constants.MMKV_USER_SESSION
import com.kaixed.kchat.utils.Constants.NICKNAME_KEY
import com.kaixed.kchat.utils.ConstantsUtils.getUsername
import com.tencent.mmkv.MMKV
import okhttp3.MultipartBody

/**
 * @Author: kaixed
 * @Date: 2024/11/23 14:15
 */
class UserProfileRepository(private val userInfoDao: UserInfoDao) {

    private val userApiService = RetrofitClient.userApiService

    // 获取用户信息
    suspend fun getUserInfo(username: String): Result<SearchUser?> {
        val requestParams = mapOf("username" to username)
        return apiCall(
            apiCall = { userApiService.getUserInfo(requestParams) },
            errorMessage = "获取用户信息失败"
        )
    }

    // 修改昵称
    suspend fun changeNickname(userRequest: UserRequest): Result<Boolean?> {
        return apiCall(
            apiCall = { userApiService.changeNickname(userRequest) },
            errorMessage = "修改昵称失败"
        ).onSuccess {
            updateNickname(userRequest.nickname!!)
        }
    }

    // 上传头像
    suspend fun uploadAvatar(file: MultipartBody.Part, username: String): Result<String> {
        return try {
            val response = userApiService.uploadAvatar(username, file)
            if (response.isSuccess()) {
                val data = response.getResponseData()
                data?.let {
                    updateDb(it)
                    Result.success(it)
                } ?: Result.failure(Exception("请求成功，但返回数据为空"))
            } else {
                Result.failure(Exception(response.getResponseMsg()))
            }
        } catch (e: Exception) {
            Result.failure(e)
        }
    }

    // 更新密码
    suspend fun updatePassword(updatePasswordRequest: UpdatePasswordRequest): Result<String?> {
        return apiCall(
            apiCall = { userApiService.updatePassword(updatePasswordRequest) },
            errorMessage = "登录失败"
        )
    }

    private suspend fun updateNickname(newNickname: String) {
        val userInfo = userInfoDao.getUserInfoByUsername(getUsername())
        MMKV.mmkvWithID(MMKV_USER_SESSION).putString(NICKNAME_KEY, newNickname)

        userInfo?.nickname = newNickname
        userInfo?.apply {
            nickname = newNickname
            userInfoDao.saveUserInfo(this)
        }
    }

    private suspend fun updateDb(url: String) {
        val userInfo = userInfoDao.getUserInfoByUsername(getUsername())
        userInfo?.apply {
            avatarUrl = url
            userInfoDao.saveUserInfo(this)
        }
    }
}
