package com.kaixed.kchat.manager

/**
 * @Author: kaixed
 * @Date: 2025/1/15 21:29
 */
import android.app.Activity
import android.content.Context
import java.util.Stack

class AppManager private constructor() {

    private val activityStack: Stack<Activity> = Stack()

    companion object {
        val instance: AppManager by lazy { AppManager() }
    }

    /**
     * 添加 Activity 到堆栈
     */
    fun addActivity(activity: Activity) {
        activityStack.add(activity)
    }

    /**
     * 获取当前 Activity（堆栈中最后一个压入的）
     */
    fun currentActivity(): Activity? {
        return if (activityStack.isNotEmpty()) {
            activityStack.lastElement()
        } else {
            null
        }
    }

    /**
     * 结束当前 Activity（堆栈中最后一个压入的）
     */
    fun finishActivity() {
        currentActivity()?.let { finishActivity(it) }
    }

    /**
     * 结束指定的 Activity
     */
    fun finishActivity(activity: Activity) {
        activityStack.remove(activity)
        activity.finish()
    }

    /**
     * 结束指定类名的 Activity
     */
    fun finishActivity(cls: Class<*>) {
        val iterator = activityStack.iterator()
        while (iterator.hasNext()) {
            val activity = iterator.next()
            if (activity.javaClass == cls) {
                iterator.remove()
                activity.finish()
            }
        }
    }

    /**
     * 结束所有 Activity
     */
    fun finishAllActivities() {
        while (activityStack.isNotEmpty()) {
            val activity = activityStack.pop()
            activity.finish()
        }
    }

    /**
     * 结束所有 Activity
     */
    fun finishAllActivities(activity: Activity) {
        activity.finishAffinity()
    }

    /**
     * 退出应用程序
     */
    fun appExit(context: Context) {
        try {
            finishAllActivities()
            val activityMgr =
                context.getSystemService(Context.ACTIVITY_SERVICE) as android.app.ActivityManager
            activityMgr.restartPackage(context.packageName) // 注意：此方法已被废弃，实际应用中可能需要调整退出逻辑
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }
}
