package com.kaixed.kchat.manager

import com.kaixed.kchat.data.DataBase
import com.kaixed.kchat.data.local.AppDatabase
import com.kaixed.kchat.data.local.entity.Messages
import com.kaixed.kchat.data.repository.MessagesRepository
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.collectLatest
import kotlin.collections.isNotEmpty

/**
 * @Author: kaixed
 * @Date: 2024/12/11 13:40
 */
object MessagesManager {

    private const val LIMIT = 20L

    private val _messages = MutableStateFlow<List<Messages>>(emptyList())

    val messages: StateFlow<List<Messages>> get() = _messages

    private var contactId: String = ""

    private var isHasHistory = false

    private val messagesDao = AppDatabase.getDatabase().messagesDao()


    private var tempIndex: Long = 0

    fun setContactId(contactId: String) {
        this.contactId = contactId
    }

    suspend fun firstLoadMessages() {
        val messages = messagesDao.getMessageByContactId(contactId, LIMIT + 1)
        handleMessages(messages)
    }

    suspend fun loadMoreMessages() {
        if (!isHasHistory) {
            return
        }
        val messages = messagesDao.getMessageByContactId(contactId, tempIndex, LIMIT + 1)
        handleMessages(messages)
    }

    private fun handleMessages(messages: List<Messages>) {
        if (messages.isNotEmpty()) {
            val size = messages.size
            isHasHistory = size > LIMIT

            _messages.value += if (isHasHistory) {
                tempIndex = messages[size - 1].msgLocalId
                messages.subList(0, LIMIT.toInt())
            } else {
                messages
            }
        }
    }

    fun deleteMessage(msgLocalId: Long) {
        DataBase.deleteMsgByLocalId(msgLocalId)
        val msg = _messages.value.toMutableList().apply {
            removeIf { it.msgLocalId == msgLocalId }
        }
        _messages.value = msg
    }

    fun resetMessages() {
        _messages.value = emptyList()
    }

    fun receiveMessage(messages: Messages) {
        if (messages.talkerId != contactId) return
        if (_messages.value.first() == messages) return
        _messages.value = _messages.value.toMutableList().apply {
            add(0, messages)
        }
    }

    fun sendMessages(messages: Messages) {
        _messages.value = mutableListOf(messages) + _messages.value
//        _messages.value = _messages.value.toMutableList().apply {
//            add(0, messages)
//        }
    }
}
