package com.kaixed.kchat.network.service

import com.kaixed.kchat.data.local.entity.UserInfo
import com.kaixed.kchat.data.model.request.RegisterRequest
import com.kaixed.kchat.data.model.response.register.Register
import com.kaixed.kchat.network.ApiResponse
import com.kaixed.kchat.network.NetworkInterface.ACCESS_TOKEN
import com.kaixed.kchat.network.NetworkInterface.LOGIN_BY_TELEPHONE
import com.kaixed.kchat.network.NetworkInterface.LOGIN_BY_USERNAME
import com.kaixed.kchat.network.NetworkInterface.REFRESH_TOKEN
import com.kaixed.kchat.network.NetworkInterface.REGISTER
import retrofit2.http.Body
import retrofit2.http.Header
import retrofit2.http.POST
import retrofit2.http.Query

/**
 * @Author: kaixed
 * @Date: 2025/1/22 18:35
 */
interface AuthApiService {

    @POST(ACCESS_TOKEN)
    suspend fun auth(
        @Header("Authorization") token: String,
        @Query("username") username: String
    ): ApiResponse<String>

    @POST(REFRESH_TOKEN)
    suspend fun refresh(
        @Header("Authorization") token: String,
        @Query("username") username: String
    ): ApiResponse<String>

    // 登录接口（根据用户名登录）
    @POST(LOGIN_BY_USERNAME)
    suspend fun loginByUsername(
        @Body requestParams: Map<String, String>,
    ): ApiResponse<UserInfo?>

    // 登录接口（根据电话登录）
    @POST(LOGIN_BY_TELEPHONE)
    suspend fun loginByTelephone(
        @Body requestParams: Map<String, String>,
    ): ApiResponse<UserInfo>

    // 注册接口
    @POST(REGISTER)
    suspend fun register(
        @Body registerRequest: RegisterRequest
    ): ApiResponse<Register>
}