package com.kaixed.kchat.network.service

import com.kaixed.kchat.data.model.request.UpdatePasswordRequest
import com.kaixed.kchat.data.model.request.UserRequest
import com.kaixed.kchat.data.model.response.search.User
import com.kaixed.kchat.data.model.search.SearchUser
import com.kaixed.kchat.network.ApiResponse
import com.kaixed.kchat.network.NetworkInterface.GET_FRIENDS
import com.kaixed.kchat.network.NetworkInterface.GET_USER_INFO
import com.kaixed.kchat.network.NetworkInterface.UPDATE_PASSWORD
import com.kaixed.kchat.network.NetworkInterface.UPDATE_USER_INFO
import com.kaixed.kchat.network.NetworkInterface.UPLOAD_AVATAR
import okhttp3.MultipartBody
import retrofit2.http.Body
import retrofit2.http.Multipart
import retrofit2.http.POST
import retrofit2.http.Part

/**
 * @Author: kaixed
 * @Date: 2024/11/15 11:00
 */
interface UserApiService {

    // 获取用户列表
    @POST(GET_FRIENDS)
    suspend fun fetchUserList(
        @Body requestParams: Map<String, String>
    ): ApiResponse<List<User>>

    // 获取用户信息
    @POST(GET_USER_INFO)
    suspend fun getUserInfo(
        @Body requestParams: Map<String, String>
    ): ApiResponse<SearchUser>

    // 更改昵称接口
    @POST(UPDATE_USER_INFO)
    suspend fun changeNickname(
        @Body userRequest: UserRequest
    ): ApiResponse<Boolean?>

    // 上传头像接口
    @Multipart
    @POST(UPLOAD_AVATAR)
    suspend fun uploadAvatar(
        @Part("username") username: String,
        @Part file: MultipartBody.Part
    ): ApiResponse<String>

    // 更改密码
    @POST(UPDATE_PASSWORD)
    suspend fun updatePassword(
        @Body updatePasswordRequest: UpdatePasswordRequest
    ): ApiResponse<String>
}
