package com.kaixed.kchat.send

import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow

class RetryQueueManager {
    // 使用 MutableStateFlow 保存当前任务列表
    private val _taskFlow = MutableStateFlow<List<MessageTask>>(emptyList())
    val taskFlow: StateFlow<List<MessageTask>> get() = _taskFlow

    // 添加任务到队列，并持久化
    fun addTask(task: MessageTask) {
        MessageRepo.save(task)
        _taskFlow.value = _taskFlow.value + task
    }

    // 更新任务状态
    fun updateTask(task: MessageTask) {
        MessageRepo.update(task)
        _taskFlow.value = _taskFlow.value.map { if (it.id == task.id) task else it }
    }

    // 从队列中移除任务
    fun removeTask(task: MessageTask) {
        MessageRepo.remove(task.id)
        _taskFlow.value = _taskFlow.value.filter { it.id != task.id }
    }

    // 获取当前已到达可上传时间的任务（按 nextRetryTime 排序）
    fun getReadyTask(): MessageTask? {
        val now = System.currentTimeMillis()
        return _taskFlow.value
            .filter { it.state == MessageState.PENDING && it.nextRetryTime <= now }
            .sortedWith(compareBy<MessageTask> { it.nextRetryTime })
            .firstOrNull()
    }
}