package com.kaixed.kchat.service

import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.MutableSharedFlow
import kotlinx.coroutines.flow.asSharedFlow

object MessageRepository : MessageSender, MessageReceiver {

    private val webSocketClient: WebSocketClient = OkHttpWebSocketClient

    // 创建一个 Flow 来发送 WebSocket 的消息
    private val _outgoingMessages = MutableSharedFlow<String>(
        replay = 0,
        extraBufferCapacity = 10
    )

    // 创建一个 Flow 来接收 WebSocket 的消息
    private val _incomingMessages = MutableSharedFlow<String>(
        replay = 0,
        extraBufferCapacity = 10
    )

    init {
        // 设置 WebSocket 消息监听器
        webSocketClient.setMessageListener { text ->
            _incomingMessages.tryEmit(text)
        }
    }

    override suspend fun sendMessage(message: String, msgLocalId: Long): Result<Unit> {
        return try {
            if (webSocketClient.send(message, msgLocalId)) {
                _outgoingMessages.emit(message)
                Result.success(Unit)
            } else {
                Result.failure(Exception("WebSocket not connected"))
            }
        } catch (e: Exception) {
            Result.failure(e)
        }
    }

    override fun observeMessages(): Flow<String> = _incomingMessages.asSharedFlow()

    fun observeOutgoingMessages(): Flow<String> = _outgoingMessages.asSharedFlow()
}