package com.kaixed.kchat.service

import android.app.Service
import android.content.Intent
import android.os.Binder
import android.os.IBinder
import android.util.Log
import com.google.gson.Gson
import com.kaixed.core.common.utils.SingleLiveEvent
import com.kaixed.kchat.data.DataBase
import com.kaixed.kchat.data.local.AppDatabase
import com.kaixed.kchat.data.local.entity.Messages
import com.kaixed.kchat.manager.ConversationManager
import com.kaixed.kchat.manager.MessagesManager
import com.kaixed.kchat.network.NetworkInterface.WEBSOCKET
import com.kaixed.kchat.network.NetworkInterface.WEBSOCKET_SERVER_URL
import com.kaixed.kchat.network.OkhttpHelper
import com.kaixed.kchat.processor.MessageProcessor
import com.kaixed.kchat.service.OkHttpWebSocketClient
import com.kaixed.kchat.utils.Constants.MMKV_COMMON_DATA
import com.kaixed.kchat.utils.ConstantsUtils.getUsername
import com.tencent.mmkv.MMKV
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.Dispatchers.IO
import kotlinx.coroutines.Job
import kotlinx.coroutines.SupervisorJob
import kotlinx.coroutines.launch
import kotlinx.serialization.json.Json
import okhttp3.Request
import okhttp3.Response
import okhttp3.WebSocket
import okhttp3.WebSocketListener
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.greenrobot.eventbus.ThreadMode


class WebSocketService : Service() {

    companion object {
        private const val TAG = "WebSocketService"
        private const val WEBSOCKET_CLOSE_CODE = 1000
    }

    private val webSocketClient: WebSocketClient = OkHttpWebSocketClient

    private val binder = LocalBinder()

    private val _messagesMutableLiveData = SingleLiveEvent<Messages?>()

    val messageLivedata: SingleLiveEvent<Messages?> get() = _messagesMutableLiveData

    private val scope = CoroutineScope(IO + SupervisorJob())

    inner class LocalBinder : Binder() {
        fun getService(): WebSocketService {
            return this@WebSocketService
        }
    }

    override fun onBind(intent: Intent?): IBinder {
        return binder
    }

    override fun onCreate() {
        super.onCreate()
        webSocketClient.connect()

        collectOutgoingMessages()
    }

    private fun collectOutgoingMessages() {
        scope.launch {
            MessageRepository.observeOutgoingMessages().collect { message ->
//                val json = Json.encodeToString(MessageModel.serializer(), message)
                val id = 0L
                webSocketClient.send(message, id)
            }
        }
    }

    override fun onStartCommand(intent: Intent?, flags: Int, startId: Int): Int {
        webSocketClient.connect()
        return START_STICKY
    }

    fun storeOwnerMsg(messages: Messages) {
        scope.launch {
            if (messages.avatarUrl == "") {
                val contact = DataBase.getContactByUsername(messages.talkerId)
                messages.avatarUrl = contact?.avatarUrl ?: ""
            }
            ConversationManager.handleMessages(messages)
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        webSocketClient.close(WEBSOCKET_CLOSE_CODE, "App exited")
    }
}
