package com.kaixed.kchat.ui.activity

import android.content.Intent
import android.os.Bundle
import androidx.activity.enableEdgeToEdge
import androidx.lifecycle.lifecycleScope
import com.bumptech.glide.Glide
import com.kaixed.kchat.data.DataBase
import com.kaixed.kchat.data.local.entity.Contact
import com.kaixed.kchat.databinding.ActivityChatDetailBinding
import com.kaixed.kchat.manager.ConversationManager
import com.kaixed.kchat.manager.MessagesManager
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.ui.widget.SwitchButton
import kotlinx.coroutines.async
import kotlinx.coroutines.launch
import org.greenrobot.eventbus.EventBus

class ChatDetailActivity : BaseActivity<ActivityChatDetailBinding>() {

    private lateinit var contactId: String

    private lateinit var contact: Contact

    override fun inflateBinding(): ActivityChatDetailBinding {
        return ActivityChatDetailBinding.inflate(layoutInflater)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

    }

    override fun initView() {
        Glide.with(this).load(contact?.avatarUrl).into(binding.ifvAvatar)
        binding.tvContactName.text = contact?.remark ?: contact?.nickname
    }

    override fun initData() {
        contactId = intent.getStringExtra("contactId") ?: ""
        lifecycleScope.launch {
            contact = DataBase.getContactByUsername(contactId)!!
            binding.ciSetDisturb.setSwitchChecked(contact?.doNotDisturb ?: false)
        }
    }

    override fun observeData() {

    }

    override fun setupListeners() {
        binding.ciSetDisturb.sbSwitch.setOnCheckedChangeListener(object :
            SwitchButton.OnCheckedChangeListener {
            override fun onCheckedChanged(button: SwitchButton, isChecked: Boolean) {
                lifecycleScope.launch {
                    ConversationManager.updateDisturbStatus(contactId, isChecked)
                }
            }
        })
        binding.ciCleanChatHistory.setOnClickListener {
            EventBus.getDefault().post(contactId)
        }

        binding.ifvAvatar.setOnClickListener {
            val intent =
                Intent(this, ContactsDetailActivity::class.java)
            intent.putExtra("contactId", contactId)
            startActivity(intent)
        }

        binding.ciSearchChatHistory.setOnClickListener {
            val intent = Intent(this, SearchChatHistory::class.java).apply {
                putExtra("contactNickname", contact?.remark ?: contact?.nickname)
                putExtra("contactAvatarUrl", contact?.avatarUrl)
                putExtra("contactId", contactId)
            }
            startActivity(intent)
        }
    }
}
