package com.kaixed.kchat.ui.activity

import android.annotation.SuppressLint
import android.content.Intent
import android.os.Bundle
import android.view.View
import androidx.activity.enableEdgeToEdge
import androidx.lifecycle.lifecycleScope
import com.bumptech.glide.Glide
import com.kaixed.kchat.data.DataBase
import com.kaixed.kchat.data.local.entity.Contact
import com.kaixed.kchat.databinding.ActivityContactsDetailBinding
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.utils.ConstantsUtils.getAvatarUrl
import com.kaixed.kchat.utils.ConstantsUtils.getNickName
import com.kaixed.kchat.utils.ConstantsUtils.getUsername
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

class ContactsDetailActivity : BaseActivity<ActivityContactsDetailBinding>() {

    private var contactId: String? = null

    private var contactNickname: String? = null

    private var isMine = false

    companion object {
        private const val TAG = "ContactsDetailActivity"
    }

    override fun inflateBinding(): ActivityContactsDetailBinding {
        return ActivityContactsDetailBinding.inflate(layoutInflater)
    }

    @SuppressLint("SetTextI18n")
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        updateContent()
    }

    override fun initView() {

    }

    override fun initData() {
        contactId = intent.getStringExtra("contactId")
        isMine = intent.getBooleanExtra("isMine", false)
    }

    override fun observeData() {
    }

    override fun setupListeners() {
        binding.tvSendMessage.setOnClickListener {
            startActivity(Intent(this, ChatActivity::class.java).apply {
                putExtra("contactId", contactId)
                putExtra("contactNickname", contactId)
            })
        }

        binding.ciSetRemarkAndLabel.setOnClickListener {
            startActivity(Intent(this, SetRemarkAndLabelActivity::class.java).apply {
                putExtra("contactId", contactId)
                putExtra("contactNickname", contactNickname)
            })
        }

        binding.ctb.setOnSettingClickListener {
            startActivity(Intent(this, DataSettingActivity::class.java).apply {
                putExtra("contactId", contactId)
            })
        }

        binding.ciPermission.setOnClickListener {
            startActivity(
                Intent(this, ContactPermissionActivity::class.java)
            )
        }
    }

    @SuppressLint("SetTextI18n")
    private fun updateContent() {
        if (isMine) {
            binding.tvContactId.text = "星联号: ${getUsername()}"
            Glide.with(this)
                .load(getAvatarUrl())
                .into(binding.ifvAvatar)
            binding.tvRemark.text = getNickName()
            binding.ciPermission.visibility = View.GONE
            binding.ciMore.visibility = View.GONE
            binding.tvVideoCall.visibility = View.GONE
            binding.view.visibility = View.GONE
            binding.ctb.ivSetting.visibility = View.GONE
            binding.ciSetRemarkAndLabel.visibility = View.GONE
            return
        }
        lifecycleScope.launch {
            val contact = getContactInfo(contactId!!)

            // 使用获取到的联系人信息更新UI（这部分已在主线程执行）
            binding.tvContactId.text = "星联号: $contactId"
            binding.tvContactSignature.text = contact?.signature
            if (contact?.remark?.isNotEmpty() == true) {
                binding.tvRemark.text = contact.remark
                contactNickname = contact.remark
                binding.tvContactName.text = "昵称：${contact.nickname}"
            } else {
                contactNickname = contact?.nickname
                binding.tvRemark.text = contact?.nickname
                binding.tvContactName.visibility = View.GONE
            }
        }
    }

    override fun onResume() {
        super.onResume()
        updateContent()
    }

    private suspend fun getContactInfo(contactId: String): Contact? {
        return withContext(Dispatchers.IO) {
            DataBase.getContactByUsername(contactId)
        }
    }
}
