package com.kaixed.kchat.ui.activity

import android.annotation.SuppressLint
import android.content.res.ColorStateList
import android.graphics.Color
import android.os.Bundle
import android.view.View
import android.view.WindowInsetsController
import androidx.activity.enableEdgeToEdge
import androidx.core.view.updateLayoutParams
import androidx.core.view.updatePadding
import androidx.core.widget.NestedScrollView
import androidx.recyclerview.widget.LinearLayoutManager
import com.bumptech.glide.Glide
import com.kaixed.core.common.utils.TextUtil
import com.kaixed.kchat.R
import com.kaixed.kchat.data.model.dynamic.Comment
import com.kaixed.kchat.data.model.dynamic.FriendCircleItem
import com.kaixed.kchat.databinding.ActivityFriendCircleBinding
import com.kaixed.kchat.ui.adapter.FriendCircleAdapter
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.utils.ConstantsUtils
import com.kaixed.kchat.utils.ConstantsUtils.getAvatarUrl
import com.kaixed.kchat.utils.ConstantsUtils.getNickName
import com.kaixed.kchat.utils.ScreenUtils.dp2px
import kotlin.math.max
import kotlin.math.min
import kotlin.random.Random

class FriendCircleActivity : BaseActivity<ActivityFriendCircleBinding>() {

    private var items: MutableList<FriendCircleItem> = mutableListOf()

    override fun inflateBinding(): ActivityFriendCircleBinding {
        return ActivityFriendCircleBinding.inflate(layoutInflater)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
    }

    override fun initData() {
        getItems()
    }

    override fun observeData() {
    }

    override fun setupListeners() {
        binding.ivBack.setOnClickListener {
            finish()
        }
    }

    private fun getItems() {
        val img = listOf(
            R.drawable.ic_1,
            R.drawable.ic_2,
            R.drawable.ic_3,
            R.drawable.ic_4,
            R.drawable.ic_5,
            R.drawable.ic_6,
            R.drawable.ic_5,
            R.drawable.ic_4,
            R.drawable.ic_3,
            R.drawable.ic_2,
        )

        for (i in 0 until 6) {
            val item = FriendCircleItem(
                username = "kaixed",
                avatarUrl = "https://img.kaixed.com/11d8d1d17289423cb762e7737cd56d12.png",
                content = "这是一条朋友圈内容",
                images = mutableListOf(),
                createTime = 1732866456839L,
                like = listOf("kaixed", "kaixed"),
                comment = listOf(Comment("kaixed", "这是一条评论", "kaixed"))
            )

            val random = Random
            val start = random.nextInt(0, 6)
            val end = random.nextInt(start + 1, 10)

            item.images.addAll(img.subList(start, end))

            items.add(item)
        }
    }


    @SuppressLint("NewApi")
    override fun initView() {
        setContent()
        binding.clTool.apply {
            updateLayoutParams {
                height = ConstantsUtils.getStatusBarHeight() + dp2px(45)
            }
            updatePadding(
                top = ConstantsUtils.getStatusBarHeight()
            )
        }

        window.insetsController?.setSystemBarsAppearance(
            0,
            WindowInsetsController.APPEARANCE_LIGHT_STATUS_BARS,
        )

        binding.nsvProfile.setOnScrollChangeListener(NestedScrollView.OnScrollChangeListener { _, _, scrollY, _, _ ->
            val percentage = scrollY.toFloat() / 150
            val imageTintList =
                ColorStateList.valueOf(if (percentage > 0.15) Color.BLACK else Color.WHITE)
            binding.ivBack.imageTintList = imageTintList
            binding.ivTakePhoto.imageTintList = imageTintList

            window.insetsController?.setSystemBarsAppearance(
                if (percentage < 0.15) 0 else WindowInsetsController.APPEARANCE_LIGHT_STATUS_BARS,
                WindowInsetsController.APPEARANCE_LIGHT_STATUS_BARS,
            )

            binding.tvTitle.visibility = if (percentage > 0.1) View.VISIBLE else View.GONE
            val alpha =
                min(1.0, max(0.0, percentage.toDouble())).toFloat()
            val color = Color.argb((alpha * 255).toInt(), 255, 255, 255)
            binding.clTool.setBackgroundColor(color)
        })

        setupRecyclerView()
    }

    private fun setContent() {
        binding.tvNickname.text = getNickName()
        val avatarUrl = TextUtil.extractDimensionsAndPrefix(getAvatarUrl())?.first
        Glide.with(this).load(avatarUrl).into(binding.ifvAvatar)
    }

    private fun setupRecyclerView() {
        val adapter = FriendCircleAdapter(this, items)
        binding.recyclerView.adapter = adapter
        binding.recyclerView.layoutManager =
            LinearLayoutManager(this, LinearLayoutManager.VERTICAL, false)
    }
}