package com.kaixed.kchat.ui.activity

import android.graphics.Color
import android.os.Bundle
import android.util.Log
import androidx.activity.enableEdgeToEdge
import androidx.core.content.ContextCompat
import androidx.core.view.updateLayoutParams
import com.bumptech.glide.Glide
import com.huawei.hms.hmsscankit.ScanUtil
import com.huawei.hms.hmsscankit.WriterException
import com.huawei.hms.ml.scan.HmsBuildBitmapOption
import com.huawei.hms.ml.scan.HmsScan
import com.kaixed.kchat.R
import com.kaixed.kchat.databinding.ActivityQrCodeBinding
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.utils.ConstantsUtils.getAvatarUrl
import com.kaixed.kchat.utils.ConstantsUtils.getNickName
import com.kaixed.kchat.utils.ConstantsUtils.getUsername
import com.kaixed.kchat.utils.ScreenUtils

class QrCodeActivity : BaseActivity<ActivityQrCodeBinding>() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        binding.ivQrcode.updateLayoutParams {
            width = ScreenUtils.getScreenWidth() / 2
            height = width
        }
    }

    override fun initView() {
    }

    override fun initData() {
        setupQrcode()
        binding.tvNickname.text = getNickName()
        Glide.with(this).load(getAvatarUrl()).error(R.drawable.ic_default_avatar)
            .into(binding.ifvAvatar)
    }

    override fun observeData() {
    }

    override fun setupListeners() {
    }

    private fun setupQrcode() {
        val content = "kchat@${getUsername()}"
        val type = HmsScan.QRCODE_SCAN_TYPE
        val width = ScreenUtils.getScreenWidth() / 2
        val bgColor = ContextCompat.getColor(this, R.color.white)
        val color = ContextCompat.getColor(this, R.color.white)
        val options = HmsBuildBitmapOption.Creator()
            .setBitmapColor(Color.parseColor("#468CFE")).setBitmapBackgroundColor(bgColor).create()
        try {
            val qrBitmap = ScanUtil.buildBitmap(content, type, width, width, options)
            binding.ivQrcode.setImageBitmap(qrBitmap)
        } catch (e: WriterException) {
            Log.e("QrCodeActivity", "WriterException: ${e.message}")
        }
    }

    override fun inflateBinding(): ActivityQrCodeBinding {
        return ActivityQrCodeBinding.inflate(layoutInflater)
    }
}