package com.kaixed.kchat.ui.activity

import android.Manifest
import android.content.Intent
import android.content.pm.PackageManager
import android.os.Bundle
import androidx.activity.enableEdgeToEdge
import androidx.core.app.ActivityCompat
import com.huawei.hms.hmsscankit.ScanUtil
import com.huawei.hms.ml.scan.HmsScan
import com.huawei.hms.ml.scan.HmsScanAnalyzerOptions
import com.kaixed.kchat.databinding.ActivityScanBinding
import com.kaixed.kchat.ui.base.BaseActivity


class ScanActivity : BaseActivity<ActivityScanBinding>() {

    companion object {
        private const val CAMERA_REQ_CODE = 100
        private const val STORAGE_REQ_CODE = 101
        const val REQUEST_CODE_SCAN = 0x012
        private const val PERMISSIONS_LENGTH = 1
    }

    private val options by lazy {
        HmsScanAnalyzerOptions.Creator().setHmsScanTypes(HmsScan.ALL_SCAN_TYPE).create()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        initPermission()

        scan()
    }

    private fun scan() {
        ScanUtil.startScan(this, REQUEST_CODE_SCAN, options)
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (resultCode == RESULT_OK && requestCode == REQUEST_CODE_SCAN && data != null) {
            val errorCode: Int = data.getIntExtra(ScanUtil.RESULT_CODE, ScanUtil.SUCCESS)
            if (errorCode == ScanUtil.ERROR_NO_READ_PERMISSION) {
                requestPermissions(
                    arrayOf(Manifest.permission.READ_EXTERNAL_STORAGE),
                    STORAGE_REQ_CODE
                )
            }
            if (errorCode == ScanUtil.SUCCESS) {
                val hmsScan: HmsScan? = data.getParcelableExtra(ScanUtil.RESULT)
                hmsScan?.let {
                    handleResult(it.showResult)
                }
            }
        }
    }

    private fun handleResult(result: String) {
        if (result.startsWith("kchat@")) {
            val contactId = result.substringAfter("kchat@")
            startActivity(Intent(this, ContactsDetailActivity::class.java).apply {
                putExtra("contactId", contactId)
            })
            finish()
        }
    }

    override fun onRequestPermissionsResult(
        requestCode: Int,
        permissions: Array<out String>,
        grantResults: IntArray
    ) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
        if (requestCode == CAMERA_REQ_CODE && grantResults.size == PERMISSIONS_LENGTH && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
            scan()
        }
        if (requestCode == STORAGE_REQ_CODE && grantResults.size == PERMISSIONS_LENGTH && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
            scan()
        }
    }


    override fun initData() {

    }

    override fun initView() {
    }

    override fun setupListeners() {
    }

    override fun observeData() {
    }

    private fun initPermission() {
        ActivityCompat.requestPermissions(
            this,
            arrayOf(Manifest.permission.CAMERA, Manifest.permission.READ_EXTERNAL_STORAGE),
            CAMERA_REQ_CODE
        )
    }

    override fun inflateBinding(): ActivityScanBinding {
        return ActivityScanBinding.inflate(layoutInflater)
    }
}