package com.kaixed.kchat.ui.activity

import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.text.SpannableString
import android.text.Spanned
import android.text.style.ForegroundColorSpan
import android.view.View
import android.view.inputmethod.InputMethodManager
import androidx.activity.enableEdgeToEdge
import androidx.activity.viewModels
import androidx.core.widget.addTextChangedListener
import com.bumptech.glide.Glide
import com.kaixed.kchat.data.DataBase
import com.kaixed.kchat.data.model.search.SearchUser
import com.kaixed.kchat.databinding.ActivitySearchFriendsBinding
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.ui.widget.LoadingDialogFragment
import com.kaixed.kchat.utils.ConstantsUtils.getUsername
import com.kaixed.kchat.viewmodel.ContactViewModel

class SearchFriendsActivity : BaseActivity<ActivitySearchFriendsBinding>() {

    private var isSearching = false

    private lateinit var userItem: SearchUser

    private lateinit var loadingDialog: LoadingDialogFragment

    private val contactViewModel: ContactViewModel by viewModels()

    private var isSearchedMine = false

    override fun inflateBinding(): ActivitySearchFriendsBinding {
        return ActivitySearchFriendsBinding.inflate(layoutInflater)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        initView()
        setObserver()
        setOnListener()
    }

    private fun setOnListener() {
        binding.etSearch.postDelayed({
            val imm = getSystemService(INPUT_METHOD_SERVICE) as InputMethodManager
            imm.showSoftInput(binding.etSearch, InputMethodManager.SHOW_IMPLICIT)
        }, 200)

        binding.clSearchUser.setOnClickListener {
            loadingDialog = LoadingDialogFragment.newInstance("正在搜索中...")
            loadingDialog.showLoading(supportFragmentManager)

            val username = binding.etSearch.text.toString()
            searchUser(username)
        }

        binding.tvCancel.setOnClickListener {
            finish()
        }
        binding.clFriends.setOnClickListener {
            val intent =
                if (isSearchedMine) {
                    Intent(this, ContactsDetailActivity::class.java).apply {
                        putExtra("isMine", getUsername() == userItem.username)
                        putExtra("contactId", userItem.username)
                    }
                } else {
                    Intent(this, ApplyFriendsDetailActivity::class.java).apply {
                        putExtra("user", userItem)
                    }
                }
            startActivity(intent)
        }

        binding.etSearch.requestFocus()
        binding.etSearch.addTextChangedListener(afterTextChanged = {
            it?.let {
                binding.tvNothing.visibility = View.INVISIBLE
                if (it.isEmpty()) {
                    binding.clFriends.visibility = View.INVISIBLE
                    binding.clSearchUser.visibility = View.INVISIBLE
                } else {
                    binding.clSearchUser.visibility = View.VISIBLE

                    val spannableString = SpannableString("搜索：$it")
                    val colorSpan = ForegroundColorSpan(Color.parseColor("#2BA245"))

                    spannableString.setSpan(
                        colorSpan, 3, it.length + 3,
                        Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                    )
                    binding.tvSearchContent.text = spannableString
                }
                isSearching = it.isNotEmpty()
            }
        })
    }

    private fun setObserver() {
        contactViewModel.searchContactResult.observe(this) { result ->
            result.onSuccess {
                it?.let {
                    isSearchedMine = it.username == getUsername()
                    if (DataBase.isMyFriend(it.username)) {
                        val username = it.username
                        val intent =
                            Intent(this, ContactsDetailActivity::class.java).apply {
                                putExtra("contactId", username)
                            }
                        startActivity(intent)
                    } else {
                        userItem = it
                        updateView(true)
                        setContent(it)
                    }
                }
            }

            result.onFailure {
                updateView(false)
            }

            loadingDialog.dismissLoading()
        }
    }

    override fun initData() {
    }

    override fun initView() {
        binding.clFriends.visibility = View.INVISIBLE
        binding.tvTitle.visibility = View.INVISIBLE
    }

    override fun setupListeners() {
    }

    override fun observeData() {
    }

    private fun searchUser(username: String) {
        contactViewModel.searchContact(username)
    }

    private fun setContent(userItem: SearchUser) {
        binding.tvNickname.text = userItem.nickname
        binding.tvSignature.text = userItem.signature
        Glide.with(this).load(userItem.avatarUrl).into(binding.ivAvatar)
    }

    private fun updateView(isSearchedUser: Boolean) {
        binding.tvNothing.visibility = if (isSearchedUser) View.GONE else View.VISIBLE
        binding.clFriends.visibility = if (isSearchedUser) View.VISIBLE else View.INVISIBLE
        binding.tvTitle.visibility = if (isSearchedUser) View.VISIBLE else View.INVISIBLE
        binding.clSearchUser.visibility = if (isSearchedUser) View.INVISIBLE else View.VISIBLE
    }
}
