package com.kaixed.kchat.ui.activity

import android.content.Intent
import android.os.Bundle
import android.view.View
import android.widget.Toast
import androidx.activity.enableEdgeToEdge
import com.kaixed.kchat.R
import com.kaixed.kchat.databinding.ActivitySettingBinding
import com.kaixed.kchat.ui.activity.setting.AboutActivity
import com.kaixed.kchat.ui.activity.setting.AccountSecurityActivity
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.ui.widget.MyBottomSheetFragment

class SettingsActivity : BaseActivity<ActivitySettingBinding>(), View.OnClickListener {

    private val context by lazy { this }

    override fun inflateBinding(): ActivitySettingBinding {
        return ActivitySettingBinding.inflate(layoutInflater)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setListener()
    }

    private fun setListener() {
        binding.itemAccountSecurity.setOnClickListener(this)
        binding.itemTeenMode.setOnClickListener(this)
        binding.itemCareMode.setOnClickListener(this)
        binding.itemNewMessageNotification.setOnClickListener(this)
        binding.itemChat.setOnClickListener(this)
        binding.itemDevice.setOnClickListener(this)
        binding.itemGeneral.setOnClickListener(this)
        binding.textPrivacy.setOnClickListener(this)
        binding.itemFriendPermission.setOnClickListener(this)
        binding.itemPersonalInfoPermission.setOnClickListener(this)
        binding.itemPersonalInfoCollection.setOnClickListener(this)
        binding.itemThirdPartyInfoSharing.setOnClickListener(this)
        binding.itemPlugin.setOnClickListener(this)
        binding.itemAboutKchat.setOnClickListener(this)
        binding.itemHelpFeedback.setOnClickListener(this)
        binding.tvSwitchAccount.setOnClickListener(this)
        binding.tvLogout.setOnClickListener(this)
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.item_account_security -> {
                val intent = Intent(this, AccountSecurityActivity::class.java)
                startActivity(intent)
            }

            R.id.item_teen_mode -> {
                // 青少年模式点击
                Toast.makeText(context, "青少年模式点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_care_mode -> {
                // 关怀模式点击
                Toast.makeText(context, "关怀模式点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_new_message_notification -> {
                // 新消息通知点击
                Toast.makeText(context, "新消息通知点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_chat -> {
                // 聊天点击
                Toast.makeText(context, "聊天点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_device -> {
                // 设备点击
                Toast.makeText(context, "设备点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_general -> {
                // 通用点击
                Toast.makeText(context, "通用点击", Toast.LENGTH_SHORT).show()
            }

            R.id.text_privacy -> {
                // 隐私点击
                Toast.makeText(context, "隐私点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_friend_permission -> {
                // 朋友权限点击
                Toast.makeText(context, "朋友权限点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_personal_info_permission -> {
                // 个人信息与权限点击
                Toast.makeText(context, "个人信息与权限点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_personal_info_collection -> {
                // 个人信息收集清单点击
                Toast.makeText(context, "个人信息收集清单点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_third_party_info_sharing -> {
                // 第三方信息共享清单点击
                Toast.makeText(context, "第三方信息共享清单点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_plugin -> {
                // 插件点击
                Toast.makeText(context, "插件点击", Toast.LENGTH_SHORT).show()
            }

            R.id.item_about_kchat -> {
                startActivity(Intent(context, AboutActivity::class.java))
            }

            R.id.item_help_feedback -> {
                // 帮助与反馈点击
                Toast.makeText(context, "帮助与反馈点击", Toast.LENGTH_SHORT).show()
            }

            R.id.tv_switch_account -> {
                // 切换账号点击
                Toast.makeText(context, "切换账号点击", Toast.LENGTH_SHORT).show()
            }

            R.id.tv_logout -> {
                val bottomSheetFragment = MyBottomSheetFragment()
                bottomSheetFragment.show(supportFragmentManager, bottomSheetFragment.tag)
            }

            else -> {
            }
        }
    }

    override fun initData() {

    }

    override fun initView() {
    }

    override fun setupListeners() {
    }

    override fun observeData() {
    }
}