package com.kaixed.kchat.ui.activity

import android.os.Bundle
import android.view.View
import android.webkit.WebChromeClient
import android.webkit.WebResourceRequest
import android.webkit.WebView
import android.webkit.WebViewClient
import android.widget.ProgressBar
import androidx.activity.enableEdgeToEdge
import com.kaixed.kchat.databinding.ActivityWebViewBinding
import com.kaixed.kchat.ui.base.BaseActivity

class WebViewActivity : BaseActivity<ActivityWebViewBinding>() {

    private lateinit var webView: WebView

    private lateinit var progressBar: ProgressBar

    private var url = ""

    override fun inflateBinding(): ActivityWebViewBinding {
        return ActivityWebViewBinding.inflate(layoutInflater)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        binding.ivSetting.setOnClickListener {
            finish()
        }

        webView = binding.webView
        progressBar = binding.progressBar

        // 初始化 WebView
        setupWebView()

        // 加载网页
        webView.loadUrl(url)

        setListener()
    }

    private fun setListener() {
        binding.ivBack.setOnClickListener {
            if (webView.canGoBack()) {
                webView.goBack()
            } else {
                finish()
            }
        }
    }

    override fun initData() {
        url = intent.getStringExtra("url") ?: ""
    }

    override fun initView() {
    }

    override fun setupListeners() {
    }

    override fun observeData() {
    }

    private fun setupWebView() {
        // 启用 JavaScript
        webView.settings.javaScriptEnabled = true

        // 设置 WebViewClient 来处理页面跳转
        webView.webViewClient = object : WebViewClient() {
            override fun onPageStarted(
                view: WebView,
                url: String,
                favicon: android.graphics.Bitmap?
            ) {
                super.onPageStarted(view, url, favicon)
                // 页面开始加载时显示 ProgressBar
                progressBar.visibility = View.VISIBLE
            }

            override fun onPageFinished(view: WebView, url: String) {
                super.onPageFinished(view, url)
                // 页面加载完成时隐藏 ProgressBar
                progressBar.visibility = View.INVISIBLE

                binding.tvTitle.visibility = View.VISIBLE
                binding.tvTitle.text = webView.title
                binding.tvUrl.text = webView.url
                binding.tvUrl.visibility = View.VISIBLE
            }

            override fun shouldOverrideUrlLoading(
                view: WebView,
                request: WebResourceRequest
            ): Boolean {
                return false
            }
        }

        // 设置 WebChromeClient 监听进度变化
        webView.webChromeClient = object : WebChromeClient() {
            override fun onProgressChanged(view: WebView, newProgress: Int) {
                super.onProgressChanged(view, newProgress)
                // 更新进度条的进度
                progressBar.progress = newProgress

                if (newProgress == 100) {
                    progressBar.visibility = View.INVISIBLE
                } else {
                    progressBar.visibility = View.VISIBLE
                }
            }
        }
    }
}