package com.kaixed.kchat.ui.activity.setting

import android.os.Bundle
import android.text.Editable
import android.text.InputFilter
import android.text.TextWatcher
import androidx.activity.enableEdgeToEdge
import androidx.activity.viewModels
import com.kaixed.kchat.data.model.request.UpdatePasswordRequest
import com.kaixed.kchat.databinding.ActivityUpdatePasswordBinding
import com.kaixed.kchat.ui.base.BaseActivity
import com.kaixed.kchat.ui.widget.LoadingDialogFragment
import com.kaixed.kchat.utils.ConstantsUtils
import com.kaixed.kchat.viewmodel.UserViewModel

class UpdatePasswordActivity : BaseActivity<ActivityUpdatePasswordBinding>() {

    private val userViewModel: UserViewModel by viewModels()

    private val loadingDialog by lazy { LoadingDialogFragment.newInstance("更改密码中...") }

    override fun inflateBinding(): ActivityUpdatePasswordBinding {
        return ActivityUpdatePasswordBinding.inflate(layoutInflater)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setListener()
        observeLiveData()
    }

    private fun observeLiveData() {
        userViewModel.updatePasswordResult.observe(this) { result ->
            result.onSuccess {
                toast("修改成功")
                finish()
            }
            result.onFailure {
                toast(it.message.toString())
            }
            loadingDialog.dismissLoading()
        }
    }

    private fun setListener() {
        binding.titleBar.setOnBtnClickListener {
            val oldPassword = binding.cetOldPassword.text.toString()
            val newPassword = binding.cetNewPassword.text.toString()
            val confirmPassword = binding.cetConfirmPassword.text.toString()
            if (confirmPassword != newPassword) {
                toast("两次密码不一致，请重新输入")
                return@setOnBtnClickListener
            } else {
                loadingDialog.showLoading(supportFragmentManager)
                val updatePassword = UpdatePasswordRequest(
                    ConstantsUtils.getUsername(), oldPassword, newPassword
                )
                userViewModel.updatePassword(updatePassword)
            }
        }

        binding.cetOldPassword.addTextChangedListener(textWatch)
        binding.cetNewPassword.addTextChangedListener(textWatch)
        binding.cetConfirmPassword.addTextChangedListener(textWatch)
    }

    private fun addEdittextFilter() {
        val noSpaceFilter = InputFilter { source, _, _, _, _, _ ->
            if (source.contains(" ")) {
                return@InputFilter ""
            }
            null
        }
        binding.cetOldPassword.filters = arrayOf(noSpaceFilter)
        binding.cetNewPassword.filters = arrayOf(noSpaceFilter)
        binding.cetConfirmPassword.filters = arrayOf(noSpaceFilter)

    }

    override fun initData() {
        binding.tvKid.text = ConstantsUtils.getUsername()
        addEdittextFilter()
    }

    override fun initView() {
    }

    override fun setupListeners() {
    }

    override fun observeData() {
    }

    private val textWatch = object : TextWatcher {
        override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {
        }

        override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
        }

        override fun afterTextChanged(s: Editable?) {
            val enable =
                binding.cetNewPassword.text?.length != 0 && binding.cetOldPassword.text?.length != 0 && binding.cetConfirmPassword.text?.length != 0
            binding.titleBar.setBtnEnable(enable)
        }
    }
}