package com.kaixed.kchat.ui.adapter

import android.content.Context
import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.bumptech.glide.Glide
import com.kaixed.core.common.utils.TextUtil
import com.kaixed.kchat.data.model.dynamic.FriendCircleItem
import com.kaixed.kchat.databinding.ItemFriendCircleBinding
import com.kaixed.kchat.utils.ScreenUtils.dp2px
import com.kaixed.kchat.utils.ScreenUtils.getScreenWidth

/**
 * @Author: kaixed
 * @Date: 2024/11/30 20:38
 */
class FriendCircleAdapter(val context: Context, val items: List<FriendCircleItem>) :
    RecyclerView.Adapter<FriendCircleAdapter.MyViewHolder>() {

    class MyViewHolder(val binding: ItemFriendCircleBinding) : RecyclerView.ViewHolder(binding.root)

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): MyViewHolder {
        val binding =
            ItemFriendCircleBinding.inflate(LayoutInflater.from(parent.context), parent, false)

        return MyViewHolder(binding)
    }

    override fun getItemCount(): Int = items.size

    override fun onBindViewHolder(holder: MyViewHolder, position: Int) {
        val item = items[position]
        holder.binding.tvNickname.text = item.username
        holder.binding.tvContent.text = item.content
        holder.binding.tvTimer.text = TextUtil.getFriendCircleTime(item.createTime)
        Glide.with(context).load(item.avatarUrl).into(holder.binding.ifvAvatar)

        val images = item.images

        val layoutParams = holder.binding.gridView.layoutParams

        layoutParams.height = getGridViewHeight(images.size)
        holder.binding.gridView.layoutParams = layoutParams

        when (images.size) {
            1, 2, 4 -> {
                holder.binding.gridView.numColumns = 2
            }

            else -> {
                holder.binding.gridView.numColumns = 3
            }
        }

        val friendCircleImageAdapter = FriendCircleImageAdapter(context, images)

        holder.binding.gridView.adapter = friendCircleImageAdapter
    }

    private fun getGridViewHeight(size: Int): Int {
        val width = getScreenWidth()
        return when (size) {
            1, 2 -> (width - dp2px(100)) / 2
            3 -> (width - dp2px(105)) / 3
            4 -> (width - dp2px(100)) + dp2px(5)
            5, 6 -> 2 * (width - dp2px(100)) / 3 + dp2px(5)
            else -> 3 * (width - dp2px(105)) / 3 + 2 * dp2px(5)
        }
    }
}