package com.kaixed.kchat.ui.base

import android.os.Bundle
import android.widget.Toast
import androidx.activity.enableEdgeToEdge
import androidx.appcompat.app.AppCompatActivity
import androidx.viewbinding.ViewBinding
import com.kaixed.kchat.manager.AppManager

/**
 * @Author: kaixed
 * @Date: 2024/11/4 10:43
 */
abstract class BaseActivity<VB : ViewBinding> : AppCompatActivity() {

    protected lateinit var binding: VB

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        binding = inflateBinding()
        setContentView(binding.root)
        initData()
        initView()
        setupListeners()
        AppManager.instance.addActivity(this)
    }

    override fun onDestroy() {
        super.onDestroy()
        AppManager.instance.finishActivity(this)
    }

    abstract fun initData()

    abstract fun initView()

    abstract fun setupListeners()

    abstract fun observeData()

    fun toast(msg: String) {
        Toast.makeText(this, msg, Toast.LENGTH_SHORT).show()
    }

    fun toast() {
        Toast.makeText(this, "暂未开发", Toast.LENGTH_SHORT).show()
    }

    abstract fun inflateBinding(): VB
}