package com.kaixed.kchat.ui.widget


import android.content.Intent
import android.os.Bundle
import android.util.TypedValue
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import android.widget.TextView
import androidx.core.content.ContextCompat
import com.google.android.material.bottomsheet.BottomSheetDialogFragment
import com.kaixed.kchat.R
import com.kaixed.kchat.data.DataBase
import com.kaixed.kchat.databinding.BottomSheetLayoutBinding
import com.kaixed.kchat.ui.activity.LoginActivity
import com.kaixed.kchat.utils.Constants.MMKV_USER_SESSION
import com.kaixed.kchat.utils.Constants.USER_LOGIN_STATUS
import com.kaixed.kchat.utils.ScreenUtils
import com.tencent.mmkv.MMKV

/**
 * @Author: kaixed
 * @Date: 2024/10/29 13:45
 */
class MyBottomSheetFragment : BottomSheetDialogFragment() {

    private var _binding: BottomSheetLayoutBinding? = null
    private val binding get() = _binding!!

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?
    ): View {
        _binding = BottomSheetLayoutBinding.inflate(inflater, container, false)
        return binding.root
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setStyle(STYLE_NORMAL, R.style.MyBottomSheetDialogStyle)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val list = arguments?.getStringArrayList("list")
        if (list != null) {
            initList(list)
        }
    }

    private fun initList(list: ArrayList<String>) {
        list.forEach {
            addTextToContainer(it)
        }
    }

    private fun addTextToContainer(item: String) {
        val textView = TextView(requireContext()).apply {
            layoutParams = LinearLayout.LayoutParams(
                LinearLayout.LayoutParams.MATCH_PARENT,
                ScreenUtils.dp2px(50)
            ).apply {
                topMargin = if (item == "取消") ScreenUtils.dp2px(8) else ScreenUtils.dp2px(1)
            }
            setBackgroundColor(ContextCompat.getColor(requireContext(), R.color.white))
            text = item
            setTextColor(ContextCompat.getColor(requireContext(), R.color.black))
            setTextSize(TypedValue.COMPLEX_UNIT_SP, 16f)
            gravity = Gravity.CENTER_HORIZONTAL or Gravity.CENTER_VERTICAL

            setOnClickListener {
                when (item) {
                    "退出账号" -> {
                        deleteAllUserData()
                        activity?.finish()
                        activity?.startActivity(Intent(
                            activity, LoginActivity::class.java
                        ).apply {
                            flags = Intent.FLAG_ACTIVITY_NEW_TASK or Intent.FLAG_ACTIVITY_CLEAR_TASK
                        })
                    }

                    "取消" -> dismiss()
                    "退出应用" -> activity?.finishAffinity()
                }
            }
        }
        binding.llBottomSheet.addView(textView)
    }

    private fun deleteAllUserData() {
        val mmkv = MMKV.mmkvWithID(MMKV_USER_SESSION)
        mmkv.clearAll()
        MMKV.defaultMMKV().putBoolean(USER_LOGIN_STATUS, false)
        DataBase.clearAllDatabase()
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}
