package com.kaixed.kchat.utils

import android.content.Context
import android.widget.ImageView
import com.bumptech.glide.Glide
import com.bumptech.glide.request.RequestOptions

object ImageLoader {

    fun loadImage(context: Context, url: String, imageView: ImageView) {
        Glide.with(context)
            .load(url)
            .into(imageView)
    }

    fun loadImage(context: Context, image: Int, imageView: ImageView) {
        Glide.with(context)
            .load(image)
            .into(imageView)
    }

    fun loadImageWithPlaceholder(context: Context, url: String, imageView: ImageView, placeholderResId: Int) {
        Glide.with(context)
            .load(url)
            .apply(getDefaultOptions().placeholder(placeholderResId))
            .into(imageView)
    }

    fun loadImageWithError(context: Context, url: String, imageView: ImageView, errorResId: Int) {
        Glide.with(context)
            .load(url)
            .apply(getDefaultOptions().error(errorResId))
            .into(imageView)
    }

    fun loadImageCircle(context: Context, url: String, imageView: ImageView) {
        Glide.with(context)
            .load(url)
            .apply(getCircleCropOptions())
            .into(imageView)
    }

    private fun getDefaultOptions(): RequestOptions {
        return RequestOptions()
            .centerCrop() // 默认居中裁剪
            .dontAnimate() // 禁止动画（如果不需要）
    }

    private fun getCircleCropOptions(): RequestOptions {
        return RequestOptions()
            .circleCrop() // 圆形裁剪
            .dontAnimate() // 禁止动画
    }
}
