package com.kaixed.kchat.utils

import android.content.Context
import android.graphics.Rect
import android.util.TypedValue
import android.view.View
import android.view.ViewTreeObserver
import com.kaixed.kchat.utils.Constants.KEYBOARD_HEIGHT
import com.kaixed.kchat.utils.Constants.KEYBOARD_HEIGHT_RATIO
import com.kaixed.kchat.utils.Constants.SCREEN_HEIGHT
import com.kaixed.kchat.utils.Constants.SCREEN_WIDTH
import com.tencent.mmkv.MMKV

/**
 * @Author: kaixed
 * @Date: 2024/12/29 22:49
 */
object ScreenUtils {
    private lateinit var appContext: Context
    private val defaultMMKV by lazy { MMKV.defaultMMKV() }

    fun init(context: Context) {
        if (!::appContext.isInitialized) {
            appContext = context.applicationContext
        }
    }


    fun getScreenHeight(): Int {
        val screenHeight = defaultMMKV.getInt(SCREEN_HEIGHT, 0)
        if (screenHeight != 0) {
            return screenHeight
        } else {
            val height = appContext.resources.displayMetrics.heightPixels
            defaultMMKV.putInt(SCREEN_HEIGHT, height)
            return height
        }
    }

    fun getScreenWidth(): Int {
        val screenWidth = defaultMMKV.getInt(SCREEN_HEIGHT, 0)
        if (screenWidth != 0) {
            return screenWidth
        } else {
            val height = appContext.resources.displayMetrics.widthPixels
            defaultMMKV.putInt(SCREEN_WIDTH, height)
            return height
        }
    }

    fun getKeyboardHeight(rootView: View, onHeightChanged: (Int) -> Unit) {
        val cachedHeight = ConstantsUtils.getKeyboardHeight()
        if (cachedHeight != Constants.KEYBOARD_DEFAULT_HEIGHT) {
            onHeightChanged(cachedHeight)
            return
        }

        val listener = object : ViewTreeObserver.OnGlobalLayoutListener {
            override fun onGlobalLayout() {
                val rect = Rect()
                rootView.getWindowVisibleDisplayFrame(rect)

                val screenHeight = getScreenHeight()
                val keypadHeight = screenHeight - rect.bottom

                if (keypadHeight > (screenHeight * KEYBOARD_HEIGHT_RATIO)) {
                    MMKV.defaultMMKV().encode(KEYBOARD_HEIGHT, keypadHeight)
                    onHeightChanged(keypadHeight) // 通过回调返回键盘高度
                    rootView.viewTreeObserver.removeOnGlobalLayoutListener(this) // 移除监听器
                }
            }
        }
        rootView.viewTreeObserver.addOnGlobalLayoutListener(listener)
    }

    fun dp2px(dp: Int): Int =
        TypedValue.applyDimension(
            TypedValue.COMPLEX_UNIT_DIP,
            dp.toFloat(),
            appContext.resources.displayMetrics
        ).toInt()
}