package com.kaixed.kchat.viewmodel

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.kaixed.kchat.data.local.AppDatabase
import com.kaixed.kchat.data.local.entity.Contact
import com.kaixed.kchat.data.model.friend.FriendRequestItem
import com.kaixed.kchat.data.model.search.SearchUser
import com.kaixed.kchat.data.repository.ContactRepository
import kotlinx.coroutines.launch

class ContactViewModel : ViewModel() {

    private val contactRepository = ContactRepository(AppDatabase.getDatabase().contactDao())

    // 获取联系人请求列表
    private val _contactRequestListResult =
        MutableLiveData<Result<List<FriendRequestItem>?>>()
    val contactRequestListResult: LiveData<Result<List<FriendRequestItem>?>> =
        _contactRequestListResult

    // 接受联系人请求
    private val _acceptContactRequestResult = MutableLiveData<Result<Contact?>>()
    val acceptContactRequestResult: LiveData<Result<Contact?>> =
        _acceptContactRequestResult

    // 添加联系人
    private val _addContactResult = MutableLiveData<Result<String?>>()
    val addContactResult: LiveData<Result<String?>> = _addContactResult

    // 搜索联系人
    private val _searchContactResult = MutableLiveData<Result<SearchUser?>>()
    val searchContactResult: LiveData<Result<SearchUser?>> = _searchContactResult

    // 获取联系人列表
    private val _contactListResult = MutableLiveData<Result<List<Contact>?>>()
    val contactListResult: LiveData<Result<List<Contact>?>> = _contactListResult

    // 删除联系人
    private val _deleteContactResult = MutableLiveData<Result<String?>>()
    val deleteContactResult: LiveData<Result<String?>> = _deleteContactResult

    // 删除联系人
    private val _setRemarkResult = MutableLiveData<Result<String?>>()
    val setRemarkResult: LiveData<Result<String?>> = _setRemarkResult

    // 设置备注
    fun setRemark(username: String, contactId: String, remark: String) {
        viewModelScope.launch {
            val result = contactRepository.setRemark(username, contactId, remark)
            _setRemarkResult.postValue(result)
        }
    }

    // 删除联系人
    fun deleteContact(username: String, contactId: String) {
        viewModelScope.launch {
            val result = contactRepository.deleteContact(username, contactId)
            _deleteContactResult.postValue(result)
        }
    }

    // 获取联系人请求列表
    fun getContactRequestList(username: String) {
        viewModelScope.launch {
            val result = contactRepository.getContactRequestList(username)
            _contactRequestListResult.postValue(result)
        }
    }

    // 接受联系人请求
    fun acceptContactRequest(username: String, contactId: String, remark: String) {
        viewModelScope.launch {
            val result = contactRepository.acceptContactRequest(username, contactId, remark)
            _acceptContactRequestResult.postValue(result)
        }
    }

    // 添加联系人
    fun addContact(contactId: String, message: String) {
        viewModelScope.launch {
            val result = contactRepository.addContact(contactId, message)
            _addContactResult.postValue(result)
        }
    }

    // 搜索联系人
    fun searchContact(username: String) {
        viewModelScope.launch {
            val result = contactRepository.searchContact(username)
            _searchContactResult.postValue(result)
        }
    }

    private val _contactListInDbResult = MutableLiveData<List<Contact>>()
    val contactListInDbResult: LiveData<List<Contact>> = _contactListInDbResult

    fun loadFriendListInDb() {
        viewModelScope.launch {
            val result = contactRepository.getContactsInDb()
            _contactListInDbResult.postValue(result ?: emptyList())
        }
    }

    fun loadFriendList(username: String) {
        viewModelScope.launch {
            val result = contactRepository.getContactList(username)
            _contactListResult.postValue(result)
        }
    }
}
