package com.kaixed.kchat.viewmodel

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.paging.Pager
import androidx.paging.PagingConfig
import androidx.paging.PagingData
import androidx.paging.cachedIn
import com.kaixed.kchat.data.local.dao.MessagesDao
import com.kaixed.kchat.data.local.entity.Messages
import kotlinx.coroutines.flow.Flow

class MessagesViewModel(
    private val messagesDao: MessagesDao
) : ViewModel() {
    private val pagingConfig = PagingConfig(
        pageSize = 20,          // 每页加载的数量
        enablePlaceholders = false,
        prefetchDistance = 5,   // 当距离边缘还有5个项目时开始加载下一页
        initialLoadSize = 40    // 首次加载的数量
    )

    // 接收当前联系人ID的消息流
    fun getMessageFlow(contactId: String): Flow<PagingData<Messages>> = Pager(
        config = pagingConfig,
        pagingSourceFactory = { messagesDao.getPagedMessages(contactId) }
    ).flow.cachedIn(viewModelScope)
}