package com.kaixed.core.common.utils

import java.text.SimpleDateFormat
import java.util.Calendar
import java.util.Date
import java.util.Locale

/**
 * @Author: kaixed
 * @Date: 2024/11/11 14:25
 */
object TextUtil {

    fun extractUrl(url: String): String {
        val regex = "(.*?)!".toRegex()
        val matchResult = regex.find(url)
        return matchResult?.groups?.get(1)?.value ?: url
    }

    //TODO 获取屏幕宽度
    fun getScreenWidth(): Int {
        return 100
    }

    /**
     * 从 URL 中提取图片的宽度和高度
     *
     * @param mainUrl 图片的 URL
     * @return 三元组，包含提取后的 URL、宽度和高度
     */
    fun extractDimensionsAndPrefix(mainUrl: String): Triple<String, Int, Int>? {
        // 定义正则表达式，提取 ! 前的部分，w 和 h 参数
        val regex = """(.*)!w=(\d+)&h=(\d+)""".toRegex()

        // 使用正则表达式进行匹配
        val matchResult = regex.find(mainUrl)

        return matchResult?.let {
            val prefix = it.groupValues[1]  // 提取 ! 前的部分
            val width = it.groupValues[2].toInt()  // 提取 w 的值
            val height = it.groupValues[3].toInt() // 提取 h 的值
            val screenWidth = getScreenWidth() / 2

            // 计算宽高比
            val ratio = width.toFloat() / screenWidth.toFloat()

            // 根据比率调整宽高，保证图片不会超过屏幕宽度
            val resultWidth = if (ratio > 1) (width / ratio).toInt() else width
            val resultHeight = if (ratio > 1) (height / ratio).toInt() else height

            Triple(prefix, resultWidth, resultHeight)  // 返回三元组
        }
    }

    fun getFriendCircleTime(timestamp: Long): String {
        val currentTime = System.currentTimeMillis()
        val difference = currentTime - timestamp

        if (difference < 60 * 1000) {
            return "现在"
        }

        if (difference < 60 * 60 * 1000) {
            return "${difference / (60 * 1000)}分钟前"
        }

        if (difference < 24 * 60 * 60 * 1000) {
            return "${difference / (60 * 60 * 1000)}小时前"
        }

        if (difference < 7 * 24 * 60 * 60 * 1000) {
            return "${difference / (24 * 60 * 60 * 1000)}天前"
        }

        return formatTimestamp(timestamp, "HH:mm")
    }

    fun getTimestampString(timestamp: Long): String {
        val currentTime = System.currentTimeMillis()
        val difference = currentTime - timestamp

        // 判断是否超过一年
        if (difference >= 365L * 24 * 60 * 60 * 1000) {
            return formatTimestamp(timestamp, "yyyy年MM月dd日")
        }

        // 判断是否是昨天
        if (isYesterday(timestamp)) {
            return "昨天 ${formatTimestamp(timestamp, "HH:mm")}"
        }

        // 判断是否超过两天
        if (difference >= 2L * 24 * 60 * 60 * 1000) {
            return formatTimestamp(timestamp, "MM月dd日")
        }

        // 否则返回时分
        return formatTimestamp(timestamp, "HH:mm")
    }

    // 判断是否为昨天
    private fun isYesterday(timestamp: Long): Boolean {
        val calendar = Calendar.getInstance()
        val currentDay = calendar.get(Calendar.DAY_OF_YEAR)
        val currentYear = calendar.get(Calendar.YEAR)

        calendar.time = Date(timestamp)
        val timestampDay = calendar.get(Calendar.DAY_OF_YEAR)
        val timestampYear = calendar.get(Calendar.YEAR)

        return currentYear == timestampYear && currentDay - timestampDay == 1
    }

    private fun formatTimestamp(timestamp: Long, pattern: String = "yyyy-MM-dd HH:mm:ss"): String {
        val dateFormat = SimpleDateFormat(pattern, Locale.getDefault())
        val date = Date(timestamp)
        return dateFormat.format(date)
    }
}
