package com.kaixed.core.network.message

import android.util.Log
import com.google.gson.Gson
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers.IO
import kotlinx.coroutines.SupervisorJob
import kotlinx.coroutines.flow.MutableSharedFlow
import kotlinx.coroutines.flow.SharedFlow
import kotlinx.coroutines.flow.asSharedFlow
import kotlinx.coroutines.launch

class MessageRepository(
    private val webSocketClient: WebSocketClient
) : MessageService {

    private val scope = CoroutineScope(IO + SupervisorJob())

    // 创建一个 Flow 来发送 WebSocket 的消息
    private val _sendMessages = MutableSharedFlow<String>(
        replay = 0,
        extraBufferCapacity = 10
    )

    private val _receivedMessages = MutableSharedFlow<MessageModel>(replay = 0, extraBufferCapacity = 100)

    val receivedMessages: SharedFlow<MessageModel> = _receivedMessages.asSharedFlow()

    init {
        // 监听WebSocket消息
        scope.launch {
            webSocketClient.observeMessages().collect { text ->
                try {
                    val wsMessage = Gson().fromJson(text, MessageModel::class.java)
                    if (wsMessage.type == "ack") {
//                        messageDao.updateMessageStatus(
//                            wsMessage.payload.msgLocalId,
//                            wsMessage.payload.msgSvrId,
//                            "sent"
//                        )
                    } else {
//                        // 存储接收到的消息
//                        messageDao.insertMessages(listOf(wsMessage.payload))
//                        // 广播给数据处理层
                        _receivedMessages.emit(wsMessage)
                    }
                } catch (e: Exception) {
                    Log.e("MessageRepository", "消息解析失败: ${e.message}")
                }
            }
        }
    }

    override suspend fun sendMessage(message: String, msgLocalId: Long): Result<Unit> {
        return try {
            if (webSocketClient.send(message, msgLocalId)) {
                _sendMessages.emit(message)
                Result.success(Unit)
            } else {
                Result.failure(Exception("WebSocket not connected"))
            }
        } catch (e: Exception) {
            Result.failure(e)
        }
    }
}