package com.kaixed.core.network.service

import com.kaixed.kchat.data.local.entity.Contact
import com.kaixed.kchat.data.model.friend.FriendRequestItem
import com.kaixed.kchat.data.model.search.SearchUser
import com.kaixed.kchat.network.ApiResponse
import com.kaixed.kchat.network.NetworkInterface.ACCEPT_FRIEND_REQUEST
import com.kaixed.kchat.network.NetworkInterface.DELETE_FRIEND
import com.kaixed.kchat.network.NetworkInterface.GET_FRIEND_REQUEST_LIST
import com.kaixed.kchat.network.NetworkInterface.SEND_FRIEND_REQUEST
import com.kaixed.kchat.network.NetworkInterface.SET_FRIEND_REMARK
import retrofit2.http.Body
import retrofit2.http.Field
import retrofit2.http.FormUrlEncoded
import retrofit2.http.GET
import retrofit2.http.POST
import retrofit2.http.Path

/**
 * @Author: kaixed
 * @Date: 2025/1/25 16:38
 */
interface FriendApiService {
    // 获取好友请求列表
    @FormUrlEncoded
    @POST(GET_FRIEND_REQUEST_LIST)
    suspend fun getContactRequestList(
        @Field("userAccount") username: String
    ): ApiResponse<List<FriendRequestItem>?>

    // 接受好友请求
    @FormUrlEncoded
    @POST(ACCEPT_FRIEND_REQUEST)
    suspend fun acceptContactRequest(
        @Field("requestId") contactId: String,
        @Field("receiverId") username: String,
        @Field("remark") remark: String
    ): ApiResponse<Contact?>

    // 添加联系人
    @FormUrlEncoded
    @POST(SEND_FRIEND_REQUEST)
    suspend fun addContact(
        @Field("senderId") senderId: String,
        @Field("receiverId") receiverId: String,
        @Field("message") message: String
    ): ApiResponse<String>

    // 搜索联系人
    @GET("users/{username}")
    suspend fun searchContact(
        @Path("username") username: String
    ): ApiResponse<SearchUser?>

    // 获取联系人列表
    @POST("friends/list")
    suspend fun getContactList(
        @Body requestParams: Map<String, String>,
    ): ApiResponse<List<Contact>?>

    // 删除联系人
    @POST(DELETE_FRIEND)
    suspend fun deleteContact(
        @Field("userId") username: String,
        @Field("contactId") contactId: String,
    ): ApiResponse<String?>

    // 设置好友备注
    @FormUrlEncoded
    @POST(SET_FRIEND_REMARK)
    suspend fun setRemark(
        @Field("userId") userId: String,
        @Field("contactId") contactId: String,
        @Field("remark") remark: String,
    ): ApiResponse<String?>
}